Cluster
========

.. py:currentmodule:: aare

.. autoclass:: Cluster
    :members:
    :undoc-members:
    :inherited-members:


Below is the API of a cluster of size :math:`3\times 3` and type ``int`` but all variants share the same API.

    .. autoclass::  aare._aare.Cluster3x3i
        :special-members: __init__
        :members:
        :undoc-members:
        :show-inheritance:
        :inherited-members:

.. note:: 
    More functions can be found in the :ref:`ClusterVector <py_clustervector>` documentation. Generally apply functions directly on the ``ClusterVector`` instead of looping over individual clusters.

